
use "$MyPath/DataOutput/forbes400_between", clear
rename cm2 cm2_top400
rename gqS gqS_top400
keep year cm2_top400  gqS_top400 
gen g_between_top400 = 0.5 *  gqS_top400 * cm2_top400
tempfile temp_forbes
save `temp_forbes'


use "$MyPath/Data/ksz", clear
* start from estate tax returns
gen gqp_estate_top001= -(log(0.01) - log(0.05)) / (log(q_estate_top001) - log(q_estate_top005))
gen gqp_estate_top01 = - (log(0.05) - log(0.25)) / (log(q_estate_top005) - log(q_estate_top025))
gen gqp_estate_top1 = - (log(1) - log(0.5)) / (log(q_estate_top1) - log(q_estate_top05))
foreach v in "1" "01" "001"{
	gen qw_estate_top`v' = q_estate_top`v' / average_estate_top`v'
}
foreach v in "1" "01" "001"{
	gen gqS_estate_top`v' = gqp_estate_top`v' * qw_estate_top`v'
}
* continue with income tax returns
gen gqp_top001 =-(log(0.01) - log(0.1)) / (log(q_top001) - log(q_top01))
gen gqp_top01 = - (log(0.1) - log(0.5)) / (log(q_top01) - log(q_top05))
gen gqp_top1 = - (log(1) - log(5)) / (log(q_top1) - log(q_top5))
foreach v in "1" "01" "001"{
	gen qw_top`v' = q_top`v' / average_top`v'
}
foreach v in "1" "01" "001"{
	gen gqS_top`v' = gqp_top`v' * qw_top`v'
}

* use estate to fill in before 1962 
foreach v in "1" "01" "001"{
	reg  gqS_top`v' gqS_estate_top`v'
	predict temp
	replace gqS_top`v' = temp if missing(gqS_top`v')
	drop temp

	ipolate gqS_top`v' year, gen(temp)
	replace gqS_top`v' = temp
	drop temp
}
keep year gqS_top* shareequity_top*
merge 1:1 year using `temp_forbes', keep(master matched) nogen
merge 1:1 year using "$MyPath/Data/forbes400_aggregate", keep(matched) nogen keepusing(cm2_ew)
keep if inrange(year, 1926, 2012)

* adjust cm2_ew ratio so that in 1983-2012, top 0.01% and Forbes 400 have same volatility
sum cm2_top400 if inrange(year, 1983, 2017)
local m1 = r(mean)
gen v = shareequity_top001^2 * cm2_ew
sum v if inrange(year, 1983, 2017)
local m2 = r(mean)
foreach v in  "1" "01" "001"{
	gen cm2_top`v' = shareequity_top`v'^2 * cm2_ew * `m1'/`m2'
	gen g_between_top`v' = gqS_top`v' / 2 * cm2_top`v'
}


twoway   (scatter gqS_top001 year, connect(l) color("51 187 238") msize(small) msymbol(diamond)) (scatter cm2_top001  year, msize(small) connect(l) color("238 119 51") msize(small) msymbol(diamond) yaxis(2)),  scheme(mg) ytitle("") ytitle("", axis(2)) legend(order(1 "gq2/(pw)" 2 "Variance") size(small) row(1))
graph export "$MyPath/Figures/Figure5_a.pdf", replace

twoway (scatter g_between_top001 year, color("1 108 89") connect(l) msize(small)) (scatter g_between_top01 year, color("28 144 153") connect(l) msize(small)) (scatter g_between_top1 year, color("$blue3") connect(l) msize(small)), legend(order(1 "Top 0.01%" 2 "Top 0.1%" 3 "Top 1%"))
graph export "$MyPath/Figures/Figure5_b.pdf", replace

keep if inrange(year, 1926, 2012)
replace g_between_top400 = log(1 + g_between_top400)
collapse (mean) gqS*  g_*  cm2_top*
replace g_between_top400 = exp(g_between_top400) - 1
gen gqS_name = "\$ g_t(q_t)q_t^2/(p\wbar_{{\scriptscriptstyle\mathcal{P}}t})\$" 
gen cm2_name = "\$\nu_t(q_t)^2\$"
gen g_between_name = "Between Term (Model-Implied)"
foreach v of varlist gqS_top* cm2_top*{
	format `v' %9.2fc
}
listtab gqS_name gqS_top1 gqS_top01 gqS_top001 using "$MyPath/Tables/TableIV_1.tex", rstyle(tabular) replace
listtab cm2_name cm2_top1 cm2_top01 cm2_top001 using "$MyPath/Tables/TableIV_2.tex", rstyle(tabular) replace
foreach v of varlist g_between_top* {
	replace `v' = 100 * `v'
	tostring `v', replace force format(%9.1fc)
	replace `v' = `v' + "\%"
}
listtab g_between_name g_between_top1 g_between_top01 g_between_top001 using "$MyPath/Tables/TableIV_3.tex", rstyle(tabular) replace

