* global MyPath  "~/Dropbox/Projects/topshares/replicationfiles"

/***************************************************************************************************
Impute wealth of Drop-offs (average, but also average log, as well as power, so that I can compute cumulants
***************************************************************************************************/

use "$MyPath/Data/forbes400_panel", clear
egen id = group(name)
keep if sample == 1
drop sample
rename rank rank_old
bys year (rank_old): gen rank = _n
drop rank_old
egen maxyear = max(year), by(id)
gen death = (dropoff_reason == "death") | (dropoff_reason == "emigration") | ((dropoff_reason == "realigned") * (maxyear == year) * (maxyear < 2017))
drop maxyear
tempfile temp
save `temp'

/* estimate dropoff */
collapse (min) networth_min = networth, by(year)
tsset year
gen networth_min_f = F.networth_min
keep year networth_min_f
tempfile temp_min
save `temp_min'

use `temp', clear
merge m:1 year using `temp_min', nogen
tsset id year
gen G = F.networth / networth
gen logG1 = log(F.networth / networth)
gen logG2 = log(F.networth / networth)^2
gen logG3 = log(F.networth / networth)^3
gen logG4 = log(F.networth / networth)^4
gen G_c = G
replace G_c = networth_min_f / networth if missing(G) & !death
assert dropoff_networth <= networth_min_f if !missing(dropoff_networth)
tempfile temp
save `temp'

/* create pdf function */
drop if missing(G_c)
gen disappear = missing(G)
qui sum year
keep  year G_c disappear 
sort year G_c disappear
gen nondisappear = 1 - disappear
egen temp = min(G_c), by(year)
replace nondisappear = 1 if G_c == temp
drop temp
gen n = 1
collapse (sum) nondisappear n, by(G_c year)
bys year (G_c): gen n_survive = sum(n)

gen p_survive = (n_survive - nondisappear)  / n_survive if nondisappear > 0
gen logp_survive = log(p_survive+ 0.000001) 
gen oG_c = - G_c
bys year (oG_c): gen logcdf = sum(logp_survive) 
gen cdf = exp(logcdf)
by year: gen cdf2 = 1.0 if _n == 1
by year: replace cdf2 = cdf[_n-1] if _n > 1
by year: gen pdf = cdf2 - cdf2[_n+1]
by year: replace pdf =  cdf2 if _n == _N
sort year G_c
by year: gen denominator = sum(pdf)
by year: gen temp = sum(pdf * G_c)
by year: gen G = temp / denominator
drop temp
gen logG_c = log(G_c)
foreach i of numlist 1/4{
	by year: gen temp = sum(pdf * logG_c^`i')
	by year: gen logG`i' = temp / denominator
	drop temp
}
keep year G_c G logG?
tempfile temp2 
save `temp2'

/* given pdf function computed imputed values */
use `temp', clear
merge m:1 year G_c using `temp2', update
assert !missing(G) if !missing(G_c)
gen imputed =  _merge == 4
drop _merge
assert G * networth <= networth_min_f + 1e-3 if imputed == 1
gen G0 = G
replace imputed = 0 if !missing(dropoff_networth)
replace G = dropoff_networth / networth if !missing(dropoff_networth)
replace logG1 = log(dropoff_networth/networth) if !missing(dropoff_networth)
replace logG2 = log(dropoff_networth/networth)^2 if !missing(dropoff_networth)
replace logG3 = log(dropoff_networth/networth)^3 if !missing(dropoff_networth)
replace logG4 = log(dropoff_networth/networth)^4 if !missing(dropoff_networth)
tsset id year
assert G != . if (year < 2017) & (death != 1) & missing(F.networth)

/* no create full sample */
tempfile temp0
save `temp0'
keep id name  familyid
duplicates drop *, force
expand 36
bys id: gen year = 1982 + _n - 1
merge 1:1 id year using `temp0', keep(master matched) nogen
replace networth = L.networth * L.G if missing(networth)
merge m:1 year using "$MyPath/Data/forbes400_aggregate", nogen keep(master matched) keepusing(pophouseholds hhnw_my)
sum pophouseholds if year == 2017
local m = r(mean)
gen N = floor(pophouseholds / (`m' / 399))
gen top = (rank <= N)
tsset id year
tempfile temp
save `temp', replace
replace top = 0 if missing(top)
replace death = 0 if missing(top)
replace death = 0 if missing(death)
bys id (year): gen t = sum(death)
drop if t == 1 & death == 0
egen familydeath = max(death * (top == 1)), by(year familyid)
replace top = 0 if missing(top)
save "$MyPath/DataOutput/forbes-full.dta", replace

/***************************************************************************************************
Decomposition
***************************************************************************************************/
foreach yyyy of numlist 1983/2016{
	use "$MyPath/DataOutput/forbes-full.dta", clear
	gen w = networth * 1000 / (hhnw_my / pophouseholds) 
	keep if inlist(year, `yyyy', `yyyy' + 1)
	tsset id year
	drop if (top == 0) & (F.top == 1) & (familydeath == 1) 
	tempfile temp`yyyy'
	topdecompose w, top(top) prefix (g_) detail  save(`temp`yyyy'')
}
drop _all
foreach yyyy of numlist 1983/2016{
	append using `temp`yyyy''
}
gen res = abs(g_total - g_within - g_between - g_demography)
assert  res <= 1e-7
drop res
sort year
gen sI = n_I / n_P1
gen sO = n_O / n_P1
gen sB = n_B / n_P1
gen sD = n_D / n_P1
gen sP = (n_P1-n_P0) / n_P1
gen rI = g_inflow / sI
gen rO = g_outflow / sO
gen rB = g_birth / sB
gen rD = g_death / sD
gen rP = g_popgrowth / sP
tempfile temp
save `temp'

use "$MyPath/Data/forbes400_aggregate", clear
tsset year
gen g_economy = (hhnw_my / pophouseholds) / (L.hhnw_my / L.pophouseholds) / (1 + infl_pce) - 1
keep year g_economy
merge 1:1 year using `temp', nogen keep(matched)
gen g_top = (1 + g_within) * (1 + g_economy) - 1

save "$MyPath/DataOutput/forbes400_decomposition", replace



/***************************************************************************************************
Estimate density and one derivative
***************************************************************************************************/
use "$MyPath/DataOutput/forbes-full.dta", clear
keep if top == 1 
collapse (min) networthmin = networth (mean) networthmean = networth, by(year)
gen qw = networthmin / networthmean
tempfile tempF
save `tempF'

/* distribution */
use "$MyPath/DataOutput/forbes-full.dta", clear
merge m:1 year using `tempF', keep(master matched) keepusing(networthmin)
keep if rank <= 400
keep if !missing(networth)
gen mnetworth = - networth
bys year (mnetworth): gen L = sum(networth)
bys year (mnetworth): gen F = sum(1)
gen logL = log(L)
gen logF = log(F)
gen lognetworth= log(networth)
gen lognetworthmin = log(networthmin)
gen h = 1
gen x = lognetworth - lognetworthmin if rank <= 400
gen weights = 1 - abs(x / h) if inrange(x, -h, h)
keep if inrange(x, 0, h)
regressby logF x [w = weights] , by(year)
gen gqp = -_b_x
merge 1:1 year using `tempF', keep(master matched) nogen
gen gqS = gqp * qw
keep year gqS gqp qw
gen zeta = gqS + 1
replace year = year + 1
tempfile temp_zeta
save `temp_zeta'

/* cumulants */
use "$MyPath/DataOutput/forbes-full", clear
keep if (rank <= 400) & (familydeath == 0)
tsset id year
merge m:1 year using `tempF'
tsset id year
gen lognetworth = log(networth)
gen lognetworthmin = log(networthmin)
sum year
local yearmin = r(min)
local yearmax = r(max)
tempfile temp
save `temp'
foreach yyyy of numlist `yearmin'/`=`yearmax'-1'{
	use `temp' if year == `yyyy'
	* triangular optimal for one sided
	gen h = 1
	gen x = lognetworth - lognetworthmin
	gen x2 = x^2
	gen weights = 1 - abs(x / h) if inrange(x, -h, h)
	reg logG1 x [w = weights]
	gen v1 = _b[_cons]
	reg logG2 x [w = weights]
	gen v2 = _b[_cons]
	reg logG3 x [w = weights]
	gen v3 = _b[_cons]
	reg logG4 x [w = weights]
	gen v4 = _b[_cons]
	keep if _n == 1
	keep year v* 
	tempfile temp`yyyy'
	save `temp`yyyy''
}
drop _all
foreach yyyy of numlist `yearmin'/`=`yearmax'-1'{
	append using `temp`yyyy''
}
gen cm2 = v2 - v1^2
gen cm3 = v3 - 3 * v2 * v1 + 2 * v1^3
gen cm4 = v4 - 4 * v3 * v1 - 3 * v2^2 + 12 * v2 * v1^2 - 6 * v1^4
gen sd = sqrt(cm2)
gen skew = cm3 / sd^3
gen kurt = cm4 / sd^4
replace year = year + 1
tempfile temp_cumulants
save `temp_cumulants'

use  "$MyPath/DataOutput/forbes400_decomposition", clear
keep year g_between
merge 1:1 year using `temp_zeta', nogen keep(matched)
merge 1:1 year using `temp_cumulants', nogen keep(matched)
gen g_cm2 = (zeta -1) / 2 * cm2
gen g_cm3 = (zeta^2-1) / 6 * cm3
gen g_cm4 = (zeta^3-1) / 24 * cm4
gen g_cm = g_cm2 + g_cm3 + g_cm4
save "$MyPath/DataOutput/forbes400_between", replace
