
/***************************************************************************************************
Figure 2 Cumulative Growth of Top Wealth Percentiles in the U.S.
***************************************************************************************************/

use "$MyPath/Data/ksz", clear
keep year topshare_*
foreach v of varlist  topshare_*{
	gen log`v' = log(`v')
	sum log`v' if year == 1983
	replace log`v' = log`v' - r(mean)
}	
merge 1:1 year using  "$MyPath/DataOutput/forbes400_decomposition", keepusing(g_total)
replace g_total = 0 if year == 1983
keep if year >= 1983
gen sumlogG_total = sum(log(1 + g_total))
label var sumlogG_total "Forbes 400"
label var logtopshare_top001 "Top 0.01%"
label var logtopshare_top01 "Top 0.1%"
label var logtopshare_top1 "Top 1%"
label var logtopshare_top10 "Top 10%"
keep if year >= 1983

twoway  (scatter sumlogG_total year, connect(l) msize(small) color(black) ) (scatter logtopshare_top001 year, connect(l) msize(small) color("1 108 89")  msymbol(triangle)) (scatter logtopshare_top01 year, connect(l) msize(small) color("28 144 153")  msymbol(diamond)) (scatter logtopshare_top1 year, connect(l) msize(small) color("103 169 207") msymbol(plus)) (scatter logtopshare_top10 year, connect(l) msize(small) color("189 201 225")  msymbol(X)) , scheme(mg) xtitle("Year") ytitle("Cumulative Growth") ylabel(`=log(1)' "1"   `=log(2)' "2" `=log(3)' "3" `=log(4)' "4")
graph export "$MyPath/Figures/Figure2.pdf", replace

/***************************************************************************************************
Table I
***************************************************************************************************/
use  "$MyPath/DataOutput/forbes400_decomposition", clear
gen period = "1983-1994" if year <= 1994
replace period = "1994-2005" if inrange(year, 1995, 2005)
replace period = "2005-2017" if inrange(year, 2006, 2017)
foreach v of varlist g_*{
	replace `v' = log(1 + `v')
}
collapse (mean) g_* r? s?, by(period)
foreach v of varlist g_*{
	replace `v' = exp(`v') - 1
	replace `v' = `v' * 100
	format `v' %9.1fc
}

tempfile temp
save `temp'


use  "$MyPath/DataOutput/forbes400_decomposition", clear
gen period = "All Years"
foreach v of varlist g_*{
	replace `v' = log(1 + `v')
}
collapse (mean) g_* r? s?, by(period)
foreach v of varlist g_*{
	replace `v' = exp(`v') - 1
	replace `v' = `v' * 100
	format `v' %9.1fc
}
append using `temp'

gen mg_economy = - g_economy
format mg_economy %9.1fc


foreach v of varlist r? {
	replace `v' = 100 * `v'
	format  `v' %9.0fc
}
foreach v of varlist s? {
	replace `v' = 100 * `v'
	format  `v' %9.1fc
}



listtab period g_total g_within  g_between  g_demography  using "$MyPath/Tables/Table1_summary.tex", rstyle(tabular) replace
listtab period g_within g_top mg_economy  using "$MyPath/Tables/Table1_within.tex", rstyle(tabular) replace
listtab period g_between g_inflow sI rI g_outflow sO rO  using "$MyPath/Tables/Table1_between.tex", rstyle(tabular) replace
listtab period g_demography g_birth sB rB g_death sD rD g_popgrowth sP rP  using "$MyPath/Tables/Table1_demography.tex", rstyle(tabular) replace

/***************************************************************************************************
Figure 3 Decomposing the Growth of the Forbes 400 Wealth Share
***************************************************************************************************/

use "$MyPath/DataOutput/forbes400_decomposition", clear

* annual
twoway (scatter g_total year, connec(l) msize(small) color(black) msymbol(circle) lwidth(medthick)) (scatter g_within year, connec(l) msize(small) color("68 118 170") msymbol(triangle))   (scatter g_between year, connec(l) msize(small) color("204 102 119") msymbol(diamond) ) (scatter g_demography year, connec(l) msize(small) color("221 170 51") msymbol(plus)) , scheme(mg)  ytitle("Growth") ylabel(-0.2 "-20%" -0.1 "10%" 0 "0%" 0.1 "10%" 0.2 "-20%" 0.3 "30%") 
graph export "$MyPath/Figures/Figure3_annual.pdf", replace

* cumulative
set obs `=_N + 1'
replace year = 1983 if missing(year)
sort year
foreach v of varlist g_*{
	replace `v' = log(1 + `v')
	replace `v' = 0 if year == 1983
	gen sum`v' = sum(`v')
	label var sum`v' "`:var label `v''"
}
twoway (scatter sumg_total year, connec(l) msize(small) color(black)  msymbol(circle) lwidth(medthick)) (scatter sumg_within year, connect(l) msize(small) color("68 118 170") msymbol(triangle)) (scatter sumg_between year, connec(l) msize(small) color("204 102 119") msymbol(diamond))  (scatter sumg_demography year, connec(l) msize(small) color("221 170 51") msymbol(plus)), ytitle("Cumulative Growth")  scheme(mg) ylabel(`=log(1)' "1"   `=log(2)' "2" `=log(3)' "3" `=log(4)' "4")
graph export "$MyPath/Figures/Figure3_cumulative.pdf", replace




/***************************************************************************************************
Figure 4 Between Term in the Forbes 400 through the Lens of the Statistical Model
***************************************************************************************************/

use "$MyPath/DataOutput/forbes400_between", clear
label var g_cm2 "Variance Term"
label var g_cm "Var. + Skew. + Kurt."
twoway   (scatter gqS year, connect(l) color("51 187 238") msize(small) msymbol(diamond)) (scatter cm2  year, msize(small) connect(l) color("238 119 51") msize(small) msymbol(diamond) yaxis(2)),  scheme(mg) ytitle("") ytitle("", axis(2)) legend(order(1 "gq2/(pw)" 2 "Variance") size(small) row(1))
graph export "$MyPath/Figures/Figure4_a.pdf", replace 
twoway   (scatter g_between year, connect(l) color("204 102 119") msize(small) msymbol(diamond)) (scatter g_cm2 year, connect(l) color("0 153 136")  msize(small)) (scatter g_cm year, connect(l) color("0 153 136")  msize(small) msymbol(triangle) lpattern(dash)),  scheme(mg)  ylabel(0 "0%"0.02 "2%" 0.04 "4%" 0.06 "6%") ytitle("") legend(order(1 "between" 2 "Due to variance" 3 "Term due to variance + skew + kurt") size(small) row(1))
graph export "$MyPath/Figures/Figure4_b.pdf", replace 


/***************************************************************************************************
Table II MODEL-IMPLIED BETWEEN TERM IN THE FORBES 40
***************************************************************************************************/
use "$MyPath/DataOutput/forbes400_between", clear
gen period = "1983-1994" if year <= 1994
replace period = "1994-2005" if inrange(year, 1995, 2005)
replace period = "2005-2017" if inrange(year, 2006, 2017)

replace g_between = log(1 + g_between)
collapse (mean) zeta qw gqp gqS sd skew kurt cm*  g_*, by(period)
replace g_between = exp(g_between) - 1
tempfile temp
save `temp'

use "$MyPath/DataOutput/forbes400_between", clear
gen period = "All Years"
replace g_between = log(1 + g_between)
collapse (mean) zeta qw gqp gqS sd skew kurt cm*  g_*, by(period)
replace g_between = exp(g_between) - 1
append using `temp'



foreach v of varlist g_* {
	replace `v' = `v' * 100
	format `v' %9.1fc
}
foreach v of varlist gqS qw gqp  sd* skew* kurt*{
	format `v' %9.2fc
}
listtab period  sd skew kurt qw gqp gqS using "$MyPath/Tables/TableII_stats.tex", rstyle(tabular) replace
listtab period g_cm g_cm2 g_cm3 g_cm4  using "$MyPath/Tables/TableII_cumulants.tex", rstyle(tabular) replace
/***************************************************************************************************
Table III DISPERSION OF WEALTH GROWTH AND DISPERSION OF FIRM-LEVEL RETURNS
***************************************************************************************************/

use "$MyPath/DataOutput/forbes400_between", clear
merge 1:1 year using "$MyPath/Data/forbes400_aggregate", keepusing(cm2_ew)
label var cm2_ew "Variance of Firm Returns"
tsset year
ivreg2 cm2 cm2_ew,  bw(3) robust
local b = _b[cm2_ew]
estimates store R_ew
qui sum year if e(sample)
estadd local period = "1983-2017"
esttab R_ew using "$MyPath/Tables/TableIII.tex", replace fragment nonumbers nolines  nodepvar   cells(b(fmt(%9.2f)) se(fmt(%9.2f) par)) stats(r2 period N, labels("\$ R^2\$" "Period" "\$ N \$") layout(@  \multicolumn{1}{c}{@} \multicolumn{1}{c}{@}) fmt("%9.2f" "%9.0fc" "%9.0fc")) nostar delimiter(&) style(tex) mlabels(none) collabels(none) label substitute(__ _)


/***************************************************************************************************
Figure D Autocorrelogram for the Within, Between and Demography Terms in the Forbes 400
***************************************************************************************************/

use  "$MyPath/DataOutput/forbes400_decomposition", clear
tsset year
tempfile postfile
tempname postname
postfile `postname' i str20 v b se using `postfile'
foreach v of varlist g_total g_within g_between g_demography{
	sum `v'
	replace `v' = (`v' - r(mean)) / r(sd)
	count if !missing(`v')
	local N = r(N)
	forval i = 1/5{
		reg `v' L`i'.`v'
		post `postname' (`i') ("`v'") (_b[L`i'.`v']) (`=1.96/sqrt(`N')')
	}
}
postclose `postname'
use `postfile', clear

twoway bar b i if v == "g_total"
gen mse = - se

replace i = (i-1) * 3 + 1
sum se if v == "g_within"
twoway (bar b i if v == "g_within", color("68 118 170")   lwidth(medthick)), yline(`=-r(mean)' `=r(mean)', lpattern(dash) lcolor(black)) yline(0, lcolor(black)) yscale(range(`=-r(mean)' `=r(mean)'))
graph export "$MyPath/Figures/FigureD_within.pdf", replace
sum se if v == "g_between"
twoway (bar b i if v == "g_between", color("204 102 119") lwidth(medthick)), yline(`=-r(mean)' `=r(mean)', lpattern(dash) lcolor(black)) yline(0, lcolor(black)) yscale(range(`=-r(mean)' `=r(mean)'))
graph export "$MyPath/Figures/FigureD_between.pdf", replace
sum se if v == "g_demography"
twoway (bar b i if v == "g_demography", color("221 170 51") lwidth(medthick)), yline(`=-r(mean)' `=r(mean)', lpattern(dash) lcolor(black)) yline(0, lcolor(black)) yscale(range(`=-r(mean)' `=r(mean)'))
graph export "$MyPath/Figures/FigureD_demography.pdf", replace




/***************************************************************************************************
Table D.I EFFECT OF USING IMPUTED VERSUS REPORTED WEALTH OF DROP-OFFS ON DECOMPOSITION
***************************************************************************************************/

use "$MyPath/DataOutput/forbes-full.dta", clear
gen w = networth * 1000 / (hhnw_my / pophouseholds) 
tsset id year
gen sample = (top == 1) & (F.top == 0) & !missing(dropoff_networth)
gen w0 = L.networth * L.G0 * 1000 / (hhnw_my / pophouseholds) 
gen g_imputed = F.w / w - 1 if sample == 1
gen g_imputed0 = F.w0 / w - 1  if sample == 1
collapse (mean) g_imputed* [w = w], by(year)
replace year = year + 1
tempfile temp 
save `temp'


use "$MyPath/DataOutput/forbes-full.dta", replace
gen w = networth * 1000 / (hhnw_my / pophouseholds) 
gen w0 = w
replace w0 = L.networth * L.G0 * 1000 / (hhnw_my / pophouseholds)  if !missing(L.G0)
gen v = abs(w0 - w) > 1 & !missing(w0)
tempfile temp0
save `temp0'
foreach yyyy of numlist 1983/2016{
	di "`yyyy'"
	use `temp0', clear
	keep if inlist(year, `yyyy', `yyyy' + 1)
	drop if (top == 0) & (F.top == 1) & (familydeath == 1) 
	sum F.w0 if F.top == 1, d
	sum F.w0 if F.top != 1, d
	tempfile temp`yyyy'
	topdecompose w0, top(top) save(`temp`yyyy'')  prefix(g_) d replace
}
drop _all
foreach yyyy of numlist 1983/2016{
	append using `temp`yyyy''
}
rename g_total g_total0
rename g_within g_within0
rename g_between g_between0
rename g_demography g_demography0
merge 1:1 year using "$MyPath/DataOutput/forbes400_decomposition", keepusing(g_within g_between) nogen keep(matched)
merge 1:1 year using `temp', nogen keep(matched)
gen period = string(year-1) + "-" + string(year)
keep if year >= 2012


preserve

foreach v of varlist g_*{
	replace `v' = log(1 + `v')
}
collapse (mean) g_*
foreach v of varlist g_*{
	replace `v' = exp(`v') - 1
}
gen period = "2011-2017"
tempfile temp
save `temp'
restore

append using `temp'


foreach v of varlist  g_* {
	replace `v' = `v' * 100
	format `v' %9.2fc
}

listtab  period  g_imputed0 g_imputed g_within0  g_within g_between0 g_between  using "$MyPath/Tables/TableDI.tex", rstyle(tabular) replace

/***************************************************************************************************
Table D.II SERIAL CORRELATION OF WEALTH GROWTH IN THE FORBES 400
***************************************************************************************************/
use "$MyPath/DataOutput/forbes-full.dta", clear
tsset id year
gen logG = log(F.networth / networth) if rank <= 400
gen logG_l = L.logG
label var logG_l "Lagged Wealth Growth"
areg logG logG_l, a(id) 
estimates store corr
qui sum year if e(sample)
estadd local period = "`=r(min)'-`=r(max)'"
estadd local FE "Individual"
esttab corr using "$MyPath/Tables/TableDII.tex", replace fragment nonumbers nolines  nodepvar   cells(b(fmt(%9.2f)) se(fmt(%9.2f) par)) stats(r2 period FE N, labels("\$ R^2\$" "Period" "FE" "\$ N \$") layout(@ \multicolumn{1}{c}{@} \multicolumn{1}{c}{@} \multicolumn{1}{c}{@}) fmt("%9.2f" "%9.0fc" "%9.0fc" "%9.0fc")) nostar delimiter(&) style(tex) mlabels(none) collabels(none) label substitute(__ _)
