/***************************************************************************************************
Impute wealth of dropoffs
***************************************************************************************************/

use "$MyPath/Data/world_panel", clear
tsset id year
gen G = F.networth / networth 
gen G_c = G
replace G_c = 1e9 / networth if missing(G) & (F.top != 1) & (death_f != 1)
drop if year == 2018
tempfile temp
save `temp'

drop if missing(G_c) 
gen disappear = missing(G) 
qui sum year
keep country year G_c disappear
sort country year G_c disappear
order country year G_c disappear
gen nondisappear = 1 - disappear 
egen temp = min(G_c), by(country year) 
replace nondisappear = 1 if G_c == temp 
drop temp
gen n = 1
collapse (sum) nondisappear n, by(G_c country year) 

bys country year (G_c): gen n_survive = sum(n) 
gen p_survive = (n_survive - nondisappear)  / n_survive if nondisappear > 0 
gen logp_survive = log(p_survive+ 0.000001) 
gen mG_c = -G_c
bys country year (mG_c): gen logcdf = sum(logp_survive) 
gen cdf = exp(logcdf)
bys country year (mG_c): gen cdf2 = 1.0 if _n == 1
bys country year (mG_c): replace cdf2 = cdf[_n-1] if _n > 1
bys country year (mG_c): gen pdf = cdf2 - cdf2[_n+1]
bys country year (mG_c): replace pdf =  cdf2 if _n == _N

sort country year G_c
by country year: gen denominator = sum(pdf)

by country year: gen numerator = sum(pdf * G_c)
by country year: gen EG1 = numerator / denominator
drop numerator

by country year: gen numerator = sum(pdf * log(G_c))
by country year: gen ElogG1 = numerator / denominator
drop numerator

by country year: gen numerator = sum(pdf * log(G_c)^2)
by country year: gen ElogG2 = numerator / denominator
drop numerator

keep country year G_c EG1  ElogG*
tempfile temp3 
save `temp3'

/* given pdf function computed imputed values */
use `temp', clear
keep if missing(G) & !missing(G_c)
merge m:1 country year G_c using `temp3', nogen
assert !missing(EG1) if !missing(networth)
replace networth = networth * EG1
replace year = year + 1
drop G G_c EG1
drop if missing(id)
gen imputed = 1
replace age = age + 1
keep year id name familyname countrycode  imputed networth family country  familycountry age ElogG*  worldbankcode lastname2 familynameid datastreamcountrycode worldbankcode wbregion lastname2
tsset id year
append using "$MyPath/Data/world_panel"
replace imputed = 0 if missing(imputed)
/* due to some rounding */
replace networth = 1e9 - 1 if networth >= 1e9 & imputed == 1
tsset id year
tempfile temp
save `temp'

use "$MyPath/Data/world_aggregate.dta", clear
egen gid = group(country)
tsset gid year
gen g_pop = pop / L.pop - 1
gen pop_l = L.pop
keep if year >= 2010
gen ntop = 50 if year == 2010
bys country (year): replace ntop = ntop[_n-1] * pop / pop[_n-1] if _n > 1
gen averagewealth = totalwealth / pop
gen ratio = ntop / pop
gen ntop_f = ntop
tempfile temp_aggregate
save `temp_aggregate'

use `temp', clear
keep if year >= 2010
keep id name familyname  country
duplicates drop *, force
tempfile tempid
save `tempid'


use `temp', clear
keep if year >= 2010
fillin id year
drop name familyname country
merge m:1 id using `tempid', nogen keep(matched)

tsset id year
merge m:1 country year using `temp_aggregate', keep(master matched)

gen mnetworth = - networth
bys country year (mnetworth imputed id): gen rank = _n
drop top
gen top = rank <= ntop & !missing(ntop) & networth >= 1e9

tsset id year
gen top_l = L.rank <= L.ntop_f & !missing(L.ntop_f)
gen death = L.death_f

drop ntop
egen ntop = sum(top), by(country year)
egen ntop_l = sum(top_l), by(country year)
tsset id year

* I only use Forbes up to 2017 ranking
drop if year == 2018
save "$MyPath/DataOutput/world-full", replace


/***************************************************************************************************
Decomposition
***************************************************************************************************/
foreach country in China Russia{
	foreach yyyy of numlist 2010/2016{
		di `yyyy'
		use "$MyPath/DataOutput/world-full.dta", clear
		gen value = networth / averagewealth
		keep if inlist(year, `yyyy', `yyyy' + 1)
		keep if country == "`country'"
		tsset id year
		replace top = . if death == 1
		drop if (top == 0) & (F.top == 1) & (F.familydeath == 1) 
		tempfile temp`country'`yyyy'
		topdecompose value, top(top) prefix (g_) detail  save(`temp`country'`yyyy'')
	}
}
clear all
gen country = "" 
foreach country in China Russia{
	foreach yyyy of numlist 2010/2016{
		append using `temp`country'`yyyy''
		cap replace country = "`country'" if missing(country)
	}
}
gen sI = n_I / n_P1
gen sO = n_O / n_P1
gen sB = n_B / n_P1
gen sD = n_D / n_P1
gen sP = (n_P1-n_P0) / n_P1
gen rI = g_inflow / sI
gen rO = g_outflow / sO
gen rB = g_birth / sB
gen rD = g_death / sD
gen rP = g_popgrowth / sP
tempfile temp
save `temp'

use "$MyPath/Data/world_aggregate.dta", clear
egen gid = group(country)
tsset gid year
gen averagewealth = totalwealth / pop
gen g_economy = averagewealth / L.averagewealth - 1
keep country year g_economy
keep if year >= 2010
merge 1:1 country year using `temp', nogen keep(matched)

gen g_top = (1 + g_within) * (1 + g_economy) - 1
save "$MyPath/DataOutput/world_decomposition", replace

/***************************************************************************************************
Estimate shape of wealth distribution and variance
***************************************************************************************************/
use "$MyPath/DataOutput/world-full", clear 
keep if top == 1
collapse  (min) networthmin = networth, by(country year)
tempfile temp
save `temp'


/*  estimate shape of wealth distribution */
use "$MyPath/DataOutput/world-full", clear 
merge m:1 country year using `temp', keep(matched) nogen
keep if imputed == 0
bys country year (mnetworth): gen L = sum(networth)
gen logL = log(L)
gen lognetworth = log(networth)
gen lognetworthmin = log(networthmin)
gen h = 1
gen x = lognetworth - lognetworthmin 
gen x2 = x^2
gen w = 1 - abs(x / h) if inrange(x, -h, h)
regressby logL x [w = w], by(country year)
gen gqS = -_b_x 
merge 1:1 country year using `temp', keep(matched) nogen
gen zeta = gqS + 1
keep country year zeta gqS
replace year = year + 1
tempfile temp_zeta
save `temp_zeta'


/*  estimate variance */
use "$MyPath/DataOutput/world-full", clear 
merge m:1 country year using `temp', keep(matched) nogen
tsset id year
gen logG = log(F.networth / networth) if imputed == 0 & familydeath ==  0
* replace for those imputed but don't replace for those after 2011
forval i = 1/2{
	gen logG`i' = logG^`i'
	replace logG`i' = F.ElogG`i' if  F.imputed == 1 & !missing(logG)
}
gen h = 2
gen x = log(networth) - log(networthmin) if imputed == 0
gen w = 1 - abs(x / h) if inrange(x, -h, h)
preserve
regressby logG1 x [w = w], by(country year)
rename _b_cons v1
keep country year v1
drop if missing(country) | missing(year)
tempfile temp
save `temp'
restore
regressby logG2 x [w = w], by(country year)
rename _b_cons v2
keep country year v2
drop if missing(country) | missing(year)
merge 1:1 country year using `temp', keep(matched) nogen
gen cm2 = v2 - v1^2
replace year = year + 1
merge 1:1 country year using `temp_zeta'
save "$MyPath/DataOutput/world_between", replace
