
/***************************************************************************************************
FIGURE E.1.— Decomposing the Annual Growth Rate of Billionaires’ Shares (2010-2017)
Table E.1.— DECOMPOSING THE GROWTH OF THE BILLIONAIRES’ WEALTH SHARE
***************************************************************************************************/
use "$MyPath/DataOutput/forbes400_decomposition", clear
merge 1:1 year using "$MyPath/DataOutput/forbes400_between", nogen
gen country = "United States"
gen datastreamcode = "US"
gen worldbankcode = "USA"
tempfile temp_us
save `temp_us'

use "$MyPath/DataOutput/world_decomposition", clear
* it makes no sense to start China  before 2009 since less than 10 billionaires, so between is huge
merge 1:1 year country using "$MyPath/DataOutput/world_between", keep(master matched) nogen
*merge m:1 year using  "$MyPath/Data/aggregate", keepusing(infl_pce) nogen keep(matched)
*replace logR_top = logR_top - log(1 + infl_pce)
append using `temp_us'
gen n = 1
replace g_cm2 = 0.5 * (zeta - 1) * cm2
keep if inrange(year, 2011, 2017)
foreach v of varlist g_* {
	replace `v' = log(1 + `v')
}
collapse  (mean) g_*  zeta* cm2 gqS  sI rI sO rO rD sD rP sP rB sB ///
(sd) seg_total = g_total seg_within = g_within  seg_between = g_between seg_demography = g_demography  ///
(sum) n, by(country)
foreach v of varlist g_* {
	replace `v' = exp(`v') - 1
}

replace seg_between = 1.96 * seg_between / sqrt(n)
replace seg_within = 1.96 * seg_within / sqrt(n)
replace seg_demography = 1.96 * seg_demography / sqrt(n)
replace seg_total = 1.96 * seg_total / sqrt(n)
gen sd = sqrt(cm2)

gen g_total_high = g_total + seg_total
gen g_total_low = g_total - seg_total
gen g_within_high = g_within + seg_within
gen g_within_low = g_within - seg_within
gen g_between_high = g_between + seg_between
gen g_between_low = g_between - seg_between
gen g_demography_high = g_demography + seg_demography
gen g_demography_low = g_demography - seg_demography

gen g = 0 if country == "United States"
replace g = 1 if country == "China"
replace g = 2 if country == "Russia"
sort g

gen ga = g * 5
gen gb = ga + 1
gen gc = ga + 2
gen gd = ga + 3
keep if !missing(g)

/* Figure E1 */
twoway (bar g_total ga, color(black)  fintensity(0) lwidth(medthick)) (rcap g_total_high g_total_low ga, color(black)) (bar g_within gb, color("68 118 170")) (rcap g_within_high g_within_low gb, color(black))  (bar g_between gc, color("204 102 119")) (rcap g_between_high g_between_low gc, color(black))  (bar g_demography gd, color("221 170 51")) (rcap g_demography_high g_demography_low gd, color(black)), xlabel(1 "`=country[1]'"  6 "`=country[2]'" 11 "`=country[3]'", noticks) legend(order(1 "Total" 3 "Within" 5 "Between" 7 "Demography") rows(1))

graph export "$MyPath/Figures/FigureE1_a.pdf", replace

twoway (bar gqS gb, color("51 187 238"))   (bar cm2 gc, color("238 119 51")) , xlabel(1 "`=country[1]'"  6 "`=country[2]'" 11 "`=country[3]'", noticks)  legend(order(1 "g(q)q{superscript:2}{&frasl}(pw{subscript:P})" 2 "{&nu}{superscript:2}") row(2))  xtitle("")
graph export "$MyPath/Figures/FigureE1_b.pdf", replace



/* Table E1 */
foreach v of varlist g_* {
	replace `v' = `v' * 100
	format `v' %9.1fc
}
gen mg_economy = -g_economy
format mg_economy  %9.1fc

foreach v of varlist s?  {
	replace `v' = 100 * `v'
	format `v' %9.1fc
}

foreach v of varlist r?  {
	replace `v' = 100 * `v'
	format `v' %9.0fc
}

tostring rB rD rP, format(%9.0fc) replace force
replace rB = "\multicolumn{1}{c}{\textemdash}" if rB == "."
replace rD = "\multicolumn{1}{c}{\textemdash}" if rD == "."
replace rP = "\multicolumn{1}{c}{\textemdash}" if rP == "."

listtab country g_total g_within  g_between  g_demography  using "$MyPath/Tables/TableE1_summary.tex", rstyle(tabular) replace
listtab country g_within  g_top  mg_economy  using "$MyPath/Tables/TableE1_within.tex", rstyle(tabular) replace
listtab country g_between g_inflow sI rI g_outflow sO rO  using "$MyPath/Tables/TableE1_between.tex", rstyle(tabular) replace
listtab country g_demography g_birth sB rB g_death sD rD g_popgrowth sP rP  using "$MyPath/Tables/TableE1_demography.tex", rstyle(tabular) replace

