/***************************************************************************************************
TABLE F.I DECOMPOSING THE GROWTH OF TOP INCOME SHARES (1979-1990)
FIGURE F.1.—Decomposing the Growth of Top Income Shares (1979-1990)
***************************************************************************************************/
use "$MyPath/Data/forbes400_aggregate", clear
keep year infl_pce
keep if inrange(year, 1979, 1990)
gen loginfl_pce = log(1 + infl_pce)
sort year
gen temp = sum(loginfl_pce)
gen pricelevel = exp(temp)
drop temp
gen period = floor((year - 1979) / 3)
collapse (mean) pricelevel, by(period)
tsset period
gen loginfl_pce = log(F.pricelevel / pricelevel) / 3
gen infl_pce = exp(loginfl_pce) - 1
drop if missing(loginfl_pce)
rename period year
keep year infl_pce
replace year = year+ 1
tempfile temp
save `temp'


use "$MyPath/Data/income_decomposition.dta", clear
merge 1:1 year p using "$MyPath/Data/income_between.dta", nogen keep(matched)
gen sI = n_I / n_P1
gen sO = n_O / n_P1
gen sB = n_B / n_P1
gen sD = n_D / n_P1
gen sP = (n_P1-n_P0) / n_P1
replace cm2 = cm2 / 3
foreach v of varlist g_* s?{
	replace `v' = (1 + `v')^(1/ 3) - 1
}

gen rI = g_inflow / sI
gen rO = g_outflow / sO
gen rB = g_birth / sB
gen rD = g_death / sD
gen rP = g_popgrowth / sP

gen repctile = 100 - p+1
tostring p, replace force
replace p = "Top "+ p + "\%"

merge m:1 year using `temp', nogen keep(matched)
replace g_economy = (1 + g_economy) / (1 + infl_pce) - 1
gen g_top = (1 + g_within) * (1 + g_economy) - 1
sort year repctile


foreach v of varlist g_*{
	replace `v' = log(1 + `v')
}
collapse (mean) g_* s? r?  gqS cm2, by(p repctile)
foreach v of varlist g_*{
	replace `v' = exp(`v') - 1
}

sort repctile

twoway (scatter g_total repctile if repctile < 100, connec(l) msize(small) color(black) msymbol(circle) lwidth(medthick)) (scatter g_within repctile if repctile < 100, connec(l) msize(small) color("68 118 170") msymbol(triangle))   (scatter g_between repctile if repctile < 100, connec(l) msize(small) color("204 102 119") msymbol(diamond) ) (scatter g_demography repctile if repctile < 100, connec(l) msize(small) color("221 170 51") msymbol(plus)) , scheme(mg)  xtitle("Percentile of Income Distribution") ytitle("") legend(order(1 "Total" 2 " Within" 3 "Between" 4 "Demography") rows(1))
graph export "$MyPath/Figures/FigureF1_a.pdf", replace

twoway   (scatter gqS repctile if repctile < 100, connect(l) color("51 187 238") msize(small) msymbol(diamond)) (scatter cm2  repctile if repctile < 100, msize(small) connect(l) color("238 119 51") msize(small) msymbol(diamond) yaxis(2)),  scheme(mg) ytitle("") legend(order(1 "g(q)q{superscript:2}{&frasl}(pw{subscript:P})" 2 "{&nu}{superscript:2}") row(2)) xtitle("Percentile of Wage Distribution")
graph export "$MyPath/Figures/FigureF2_b.pdf", replace

keep if inlist(repctile, 1, 91, 99)
foreach v of varlist g_* {
	replace `v' = `v' * 100
	format `v' %9.1fc
}
gen mg_economy = - g_economy
format mg_economy %9.1fc
foreach v of varlist s? {
	replace `v' = 100 * `v'
	tostring `v', format(%9.1fc) replace force
}
foreach v of varlist r?{
	replace `v' = 100 * `v'
	tostring `v', format(%9.0fc) replace force
}
replace rI = "\multicolumn{1}{c}{\textemdash}" if p == "Top 100\%"
replace rO = "\multicolumn{1}{c}{\textemdash}" if p == "Top 100\%"
listtab p g_total g_within  g_between g_demography  using "$MyPath/Tables/TableF1_summary.tex", rstyle(tabular) missnum("\multicolumn{1}{c}{\textemdash}")  replace
listtab p g_within g_top mg_economy  using "$MyPath/Tables/TableF1_within.tex", rstyle(tabular) replace
listtab p g_between g_inflow sI rI g_outflow sO rO  using "$MyPath/Tables/TableF1_between.tex", rstyle(tabular) missnum("\multicolumn{1}{c}{\textemdash}")  replace
listtab p g_demography g_birth sB rB g_death sD rD g_popgrowth sP rP  using "$MyPath/Tables/TableF1_demography.tex", rstyle(tabular) missnum("\multicolumn{1}{c}{\textemdash}")  replace



