* This code creates the files income_decomposition and income_between from the IRS Public Sample File on the NBER server
/***************************************************************************************************
Clean dataset
***************************************************************************************************/

use "/homes/data/soi/dta/p1979.dta", clear
forval X = 1980(1)1990{
	append using  "/homes/data/soi/dta/p`X'"
}
keep if mars == 2

drop year
gen year = 1900 + flpdyr
keep if inrange(year,  1979, 1990)

gen income_capital = divagi
replace income_capital = divint + inty if missing(income_capital)
replace income_capital = income_capital + rentyl + ryltyl
gen income = max(agi - cgagi - income_capital, 0)

tsset id year
keep id year ssncode income
drop if  (year >= 1987) & (ssncode == 3)
drop if inlist(year, 1982, 1984, 1986) & ssncode == 2
drop if id == 5655
fillin id year
tsset id year

/* averages every 3 years */
gen period = floor((year - 1979) / 3)
keep if ssncode == 1
gen n = 1
gcollapse (mean) income (sum) n, by(id period) fast
keep if n == 3
rename period year
drop n
gegen temp = mean(income), by(year)
replace income = 0.1 * temp if income < 0.1 * temp
bys year (income): gen rank = _N - _n + 1
bys year: gen Ntot  = _N
gegen income_mean = mean(income), by(year)
tsset id year
save "~/bulk/master", replace

/***************************************************************************************************
Create income_between
***************************************************************************************************/
use "~/bulk/master", clear
gcollapse (mean) income, by(year)
tsset year
gen g_economy = income / L.income - 1
keep year g_economy
tempfile temp_economy
save `temp_economy'

use "~/bulk/master", clear
gen value = income / income_mean
tempfile temp
save `temp'

forval p = 1/100{
	use `temp', clear
	gen top = rank <= floor(`p' / 100 * Ntot)
	tempfile temp_`p'
	topdecompose value, top(top) detail prefix (g_)  save(`temp_`p'')  replace
}

drop _all
gen p = .
forval p = 1/100{
	append using `temp_`p''
	replace p = `p' if missing(p)
}
merge m:1  year using `temp_economy', nogen keep(matched)
save "out/income_decomposition", replace

/***************************************************************************************************
Create income_decomposition
***************************************************************************************************/

forval p = 1/100{
	use "~/bulk/master", clear
	gen N = floor(`p' / 100 * Ntot)
	gen top = rank <= N
	keep if top == 1
	gcollapse (mean) incomemean = income (min) incomemin = income, by(year)
	gen zeta1 = 1 / (1 - incomemin / incomemean)
	keep year zeta1 incomemin
	sort year
	tempfile temp0
	save `temp0'

	use "~/bulk/master", clear
	sort year
	merge m:1 year using `temp0', nogen sorted
	gen mincome = -income
	bys year (mincome): gen F = sum(1)
	gen logF = log(F)
	tsset id year
	gen g = F.income / income
	gen logincome = log(income)
	gen logincomemin = log(incomemin)
	sum year
	local yearmin = r(min)
	local yearmax = r(max)
	tempfile temp
	save `temp'

	forval yyyy = `yearmin'/`=`yearmax'-1'{
		use `temp' if year == `yyyy', clear
		gen h = 0.3 * sqrt(3)
		gen x = logincome - logincomemin
		gen w = 1 - abs(x / h) if inrange(x, -h, h)
		cap reg logF x [w = w]
		gen zeta2 = -_b[x]
		gen logg = log(g)
		gen logg2 = logg^2
		qui cap reg logg x [w = w]
		gen v1 = _b[_cons]
		qui cap reg logg2 x [w = w]
		gen v2 = _b[_cons]
		keep if _n == 1
		keep year zeta1 zeta2  v*
		tempfile temp`yyyy'
		save `temp`yyyy''
	}
	drop _all
	forval yyyy = `yearmin'/`=`yearmax'-1'{
		append using "`temp`yyyy''"
	}
	gen gqS = (zeta1 - 1) / zeta1 * zeta2
	gen cm2 = v2 - v1^2
	replace year = year + 1
	tempfile temp_`p'
	save `temp_`p''
}
drop _all
gen p = .
forval p = 1/100{
	append using `temp_`p''
	replace p = `p' if missing(p)
}
save "out/income_between", replace
